@@ -1,6 +1,6 @@
 get.level <- function(data,level)
 {
-    x <- full.hts(data)
+    x <- allts(data)
     j <- rep(1:length(x$m),x$m)
-    return(x$gma[,j==level])
+    return(x[,j==level])
 }
