@@ -5,7 +5,7 @@
 td.gsF <- function(data,h,p.f.mat,c.sum,scoef.l) 
 { 
     # Method "F" from Gross and Sohl implemented here
-    level.ave <- split(matrix(colMeans(full.hts(data)$gma),nrow=1),rep(1:length(data$m),data$m))
+    level.ave <- split(matrix(colMeans(allts(data)),nrow=1),rep(1:length(data$m),data$m))
     tdm2.l <- list(matrix(p.f.mat[,1],ncol=1))
     if(length(data$m)>1)
     {
@@ -18,7 +18,7 @@ td.gsF <- function(data,h,p.f.mat,c.sum,scoef.l)
             tdm2.l[[j]] <- tmp.mat * ppl.con
         }
     }
-    tdm2.l <- ts(tdm2.l[[length(data$m)]],start=end(data$y)[1]+1,f=frequency(data$y))
+    tdm2.l <- ts(tdm2.l[[length(data$m)]],start=tsp(data$y)[2]+1/frequency(data$y),f=frequency(data$y))
     colnames(tdm2.l) <- colnames(data$y)
     return(hts(y=tdm2.l, g=data$g))
 } 
